--[[ $Id$
   Copyright (c) Brett England, 2013

   No commercial use.
   No redistribution at profit.
   All derivative work must retain this message and
   acknowledge the work of the original author.
--]]
local bsc = require("bsc")
local xap = require("xap")
local ui = require("ui")

-- UI helper functions
function toggle(v, xpos, ypos)
    v.x = xpos
	v.y = ypos
	v.size = v.size or 20
	v.default = v.default or "glossy_button_red.png"
	v.on = v.on or "glossy_button_green.png"
	bsc.newToggle(v)
end

function button(v, xpos, ypos)
	bsc.newButton {
			defaultSrc = v.icon, defaultX = 80, defaultY = 80, -- img, width, height
			x=xpos, y=ypos, -- position
			size=30, -- font size
			offset=-18,
			label={text=v.label, offset=20, size=18, textColor={ 0, 0, 0, 255 }},
			textColor={ 0, 0, 0, 255 }, -- r,g,b,a
			xapSource=v.xapSource,
	}
end

local grid = {
        {
		  {c=ui.newLabel, bounds={0,0,display.contentWidth,50}, text="XAP UI demo", align="center", size=30}
		},
        { -- ROW 1
		 {c=toggle, text="Relay 1", xapSource="dbzoo.livebox.Controller:relay.1", size=18},
		 {c=toggle, text="Relay 2", xapSource="dbzoo.livebox.Controller:relay.2", size=18},
		 {c=toggle, text="Relay 3", xapSource="dbzoo.livebox.Controller:relay.3", size=18},
		 {c=toggle, text="Relay 4", xapSource="dbzoo.livebox.Controller:relay.4", size=18},
		},
        { -- ROW 2
		 {c=toggle, text="RF 1", xapSource="dbzoo.livebox.Controller:rf.1"},
		 {c=toggle, text="RF 2", xapSource="dbzoo.livebox.Controller:rf.2"},
		 {c=toggle, text="RF 3", xapSource="dbzoo.livebox.Controller:rf.3"},
		 {c=toggle, text="RF 4", xapSource="dbzoo.livebox.Controller:rf.4"},
		},			 
		{ -- ROW 3
		 {c=button, icon="outside-temp-icon.png", label="Outside", xapSource='dbzoo.livebox.jeenode:outside.temp2'},
		 {c=button, icon="inside-temp-icon.png", label="Lounge", xapSource='dbzoo.cheese.jeenode:4.temp'},
		 {c=button, icon="inside-temp-icon.png", label="Office", xapSource='dbzoo.livebox.controller:1wire.1'},
		 {c=button, icon="inside-temp-icon.png", label="Store", xapSource='dbzoo.livebox.jeenode:store.temp'},
		},
		{ -- ROW 4
		 {c=button, icon="lightbulb.png", label="Sunshine", xapSource='dbzoo.livebox.jeenode:outside.light'},
		 {c=button, icon="lightbulb.png", label="Lounge", xapSource='dbzoo.cheese.jeenode:4.light'},
		 {},
		 {c=button, icon="lightbulb.png", label="Store", xapSource='dbzoo.livebox.jeenode:store.light'},
		},
		{ -- ROW 5
		 {c=toggle, text="lobat", xapSource="dbzoo.livebox.jeenode:outside.lobat", readOnly=true},
		 {c=toggle, text="lobat", xapSource="dbzoo.cheese.jeenode:4.lobat", readOnly=true},
		 {},
		 {},
		}
}

display.newImage( "background.png", true)

-- Create QUIT button
ui.newButton{
    text = "Quit", size = 20,
    defaultSrc="buttonBlue.png", defaultX = 298, defaultY=56,
	overSrc = "buttonBlueOver.png", overX = 298, overY=56, 
	x = display.contentCenterX,
	y = display.contentHeight-40,
    onRelease = function() native.requestExit() end
}

-- Setup GLOBAL xap_server object
xap_server = xap.TCPServer("home.dbzoo.com")
xap_server:setSource("dbzoo.corona.applet")

-- At this point we can't really do much...
if not xap_server:isConnected() then  
	ui.newLabel{ bounds={0,display.contentCenterY,
	                     display.contentWidth,display.contentHeight}, 
	             text= xap_server:getErrorMessage(), 
				 align="center", 
				 size=12}
  return
end

-- Render grid
local ypos = 0, xpos
for _,r in ipairs(grid) do		
	xpos=40
	for _,v in pairs(r) do
		if v.c then
			v.c(v, xpos, ypos)
		end
		 xpos = xpos + 80
	end
	ypos = ypos + 80
end

-- Start XAP engine
xap_server:start()

-- Capture application shutdown		
local onSystem = function( event )
    if event.type == "applicationExit" then
        xap_server:stop()
    end
end
Runtime:addEventListener( "system", onSystem )
